@@ -15,7 +15,7 @@ parser.add_argument(
 parser.add_argument('table', help="Table name or 'all' to use the config", nargs='?')
 parser.add_argument('--config', help="Config file", default='./pgwarehouse_conf.yaml', required=False)
 parser.add_argument('--data', help="Temp storage directory", default='./pgw_data', required=False)
-parser.add_argument('--backend', help="Warehouse type", choices=['clickhouse', 'snowflake'], required=False)
+parser.add_argument('--backend', help="Warehouse type", choices=['clickhouse', 'snowflake', 'duckdb'], required=False)
 parser.add_argument('--last-modified', help="Timestamp column to use to select records for Upsert", required=False)
 parser.add_argument('-d', '--debug', action='store_true', required=False)
 
